/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IMethodPermission.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.io.Serializable;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IMethodDD;

/**
 * Interface for element method-permission.
 * @author Florent Benoit
 */
public interface IMethodPermission extends Serializable {

    /**
     * Name of this element.
     */
    String NAME = "method-permission";

    /**
     * Sets the unchecked flag.
     * @param unchecked the given boolean value.
     */
    void setUnchecked(final boolean unchecked);

    /**
     * Is it unchecked ?.
     * @return true if it is unchecked, else false.
     */
    boolean isUnchecked();

    /**
     * Add a new Method.
     * @param method the given method.
     */
    void addMethod(final IMethodDD method);

    /**
     * @return list of methods.
     */
    List<IMethodDD> getMethods();

    /**
     * Gets the name of the role.
     * @return the role's name.
     */
    List<String> getRoleNameList();

    /**
     * Add the given role.
     * @param roleName the name of the role.
     */
    void addRoleName(final String roleName);

}
